summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TButton.php
diff options
context:
space:
mode:
authorFabio Bas <ctrlaltca@gmail.com>2015-01-25 20:04:57 +0100
committerFabio Bas <ctrlaltca@gmail.com>2015-01-25 20:04:57 +0100
commite4999b25052d1ad9400a0f9fd5289a49eea1bddc (patch)
tree50e9b819fc3326cf08e882b648f8dafc8fec3fa4 /framework/Web/UI/WebControls/TButton.php
parent5230f8f8a86fc1ae5d90f8c74ae65c93e197502b (diff)
More namespace changes
Changed version to 3.2.99; Attempt at fixing autoloading fixed enough namespaces to have some demos running
Diffstat (limited to 'framework/Web/UI/WebControls/TButton.php')
-rw-r--r--framework/Web/UI/WebControls/TButton.php12
1 files changed, 7 insertions, 5 deletions
diff --git a/framework/Web/UI/WebControls/TButton.php b/framework/Web/UI/WebControls/TButton.php
index ed882654..6591bb76 100644
--- a/framework/Web/UI/WebControls/TButton.php
+++ b/framework/Web/UI/WebControls/TButton.php
@@ -10,6 +10,8 @@
*/
namespace Prado\Web\UI\WebControls;
+use Prado\Web\UI\TCommandEventParameter;
+use Prado\TPropertyValue;
/**
* TButton class
@@ -47,7 +49,7 @@ namespace Prado\Web\UI\WebControls;
* @package Prado\Web\UI\WebControls
* @since 3.0
*/
-class TButton extends TWebControl implements IPostBackEventHandler, IButtonControl, IDataRenderer
+class TButton extends \Prado\Web\UI\WebControls\TWebControl implements \Prado\Web\UI\IPostBackEventHandler, \Prado\Web\UI\IButtonControl, \Prado\IDataRenderer
{
/**
* @return string tag name of the button
@@ -197,7 +199,7 @@ class TButton extends TWebControl implements IPostBackEventHandler, IButtonContr
* The method raises 'OnCommand' event to fire up the event handlers.
* If you override this method, be sure to call the parent implementation
* so that the event handlers can be invoked.
* @param TCommandEventParameter event parameter to be passed to the event handlers
*/
public function onCommand($param)
{
@@ -219,7 +221,7 @@ class TButton extends TWebControl implements IPostBackEventHandler, IButtonContr
if($this->getCausesValidation())
$this->getPage()->validate($this->getValidationGroup());
$this->onClick(null);
- $this->onCommand(new TCommandEventParameter($this->getCommandName(),$this->getCommandParameter()));
+ $this->onCommand(new \Prado\Web\UI\TCommandEventParameter($this->getCommandName(),$this->getCommandParameter()));
}
/**
@@ -240,7 +242,7 @@ class TButton extends TWebControl implements IPostBackEventHandler, IButtonContr
/**
* Returns the caption of the button.
* This method is required by {@link IDataRenderer}.
* It is the same as {@link getText()}.
* @return string caption of the button.
* @see getText
@@ -253,7 +255,7 @@ class TButton extends TWebControl implements IPostBackEventHandler, IButtonContr
/**
* Sets the caption of the button.
* This method is required by {@link IDataRenderer}.
* It is the same as {@link setText()}.
* @param string caption of the button
* @see setText
@@ -197,7 +199,7 @@ class TButton extends TWebControl implements IPostBackEventHandler, IButtonContr
* If you override this method, be sure to call the parent implementation
* so that the event handlers can be invoked.
- * @param TCommandEventParameter event parameter to be passed to the event handlers
+ * @param \Prado\Web\UI\TCommandEventParameter event parameter to be passed to the event handlers
*/
public function onCommand($param)
@@ -240,7 +242,7 @@ class TButton extends TWebControl implements IPostBackEventHandler, IButtonContr
/**
* Returns the caption of the button.
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link getText()}.
* @return string caption of the button.
@@ -253,7 +255,7 @@ class TButton extends TWebControl implements IPostBackEventHandler, IButtonContr
/**
* Sets the caption of the button.
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link setText()}.
* @param string caption of the button